==> cdi-tck-impl-1.1.0.CR1-sources.jar: org/jboss/cdi/tck/tests/extensions/beanManager/broken/event/FireContainerLifecycleEventTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.extensions.beanManager.broken.event;

import static org.jboss.cdi.tck.TestGroups.INTEGRATION;
import static org.jboss.cdi.tck.cdi.Sections.BM_FIRE_EVENT;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * An extension is not allowed to fire an event with runtime type assignable to the type of a container lifecycle event. Tested
 * extension fires such events during BeforeBeanDiscovery notification.
 * 
 * @author Martin Kouba
 * @author Jozef Hartinger
 * 
 */
@SpecVersion(spec = "cdi", version = "20091101")
public class FireContainerLifecycleEventTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(FireContainerLifecycleEventTest.class)
                .withExtension(FooExtension.class).build();
    }

    @Test(groups = INTEGRATION)
    @SpecAssertion(section = BM_FIRE_EVENT, id = "f")
    public void testFireContainerLifecycleEvent() {
        for (Object event : ContainerLifecycleEvents.CONTAINER_LIFECYCLE_EVENTS) {
            try {
                getCurrentManager().fireEvent(event);
                throw new IllegalStateException("Expected exception (IllegalArgumentException) not thrown");
            } catch (IllegalArgumentException expected) {
            }
        }
    }

}

==> cdi-tck-impl-1.2.0.CR1-sources.jar: org/jboss/cdi/tck/tests/extensions/beanManager/broken/event/FireContainerLifecycleEventTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.extensions.beanManager.broken.event;

import static org.jboss.cdi.tck.TestGroups.INTEGRATION;
import static org.jboss.cdi.tck.cdi.Sections.BM_FIRE_EVENT;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * An extension is not allowed to fire an event with runtime type assignable to the type of a container lifecycle event. Tested
 * extension fires such events during BeforeBeanDiscovery notification.
 * 
 * @author Martin Kouba
 * @author Jozef Hartinger
 * 
 */
@SpecVersion(spec = "cdi", version = "1.1 Final Release")
public class FireContainerLifecycleEventTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(FireContainerLifecycleEventTest.class)
                .withExtension(FooExtension.class).build();
    }

    @Test(groups = INTEGRATION)
    @SpecAssertion(section = BM_FIRE_EVENT, id = "f")
    public void testFireContainerLifecycleEvent() {
        for (Object event : ContainerLifecycleEvents.CONTAINER_LIFECYCLE_EVENTS) {
            try {
                getCurrentManager().fireEvent(event);
                throw new IllegalStateException("Expected exception (IllegalArgumentException) not thrown");
            } catch (IllegalArgumentException expected) {
            }
        }
    }

}
